﻿//
// Copyright (c) 2016, MindFusion LLC - Bulgaria.
//

using System;
using System.Windows.Forms;
using System.Drawing;


namespace MindFusion.Spreadsheet.WinForms.Samples.CS.Features
{
	public partial class FreezingForm : Form
	{
		public FreezingForm()
		{
			InitializeComponent();

			var sheet = workbook.Worksheets[0];

			sheet.BeginInit();

			sheet.Columns[0, 6].Width = Measure.Point(80);
			sheet.Rows[0].Height = Measure.Point(20);
			sheet.Rows[202].Height = Measure.Point(20);

			sheet.Cells["A1"].Data = "Order Number";
			sheet.Cells["B1"].Data = "Invoice Number";
			sheet.Cells["C1"].Data = "Unit Price";
			sheet.Cells["D1"].Data = "Quantity";
			sheet.Cells["E1"].Data = "Subtotal";
			sheet.Cells["F1"].Data = "VAT";
			sheet.Cells["G1"].Data = "Total";

			for (int i = 0; i <= 200; i++)
			{ 
				string row = (i + 2).ToString();
				sheet.Cells["A" + row].Data = "'" + (i + 1).ToString("D8");
				sheet.Cells["B" + row].Data = string.Format("'201402{0}", (i + 1).ToString("D5"));
				sheet.Cells["C" + row].Data = (rnd.Next(2, 29) + rnd.Next(12, 99) % 3 == 0 ? 0.49 : 0.99).ToString("C");
				sheet.Cells["D" + row].Data = rnd.Next(1, 5);
				sheet.Cells["E" + row].Data = string.Format("=C{0}*D{0}", row);
				sheet.Cells["F" + row].Data = string.Format("=E{0}*0.2", row);
				sheet.Cells["G" + row].Data = string.Format("=E{0}*1.2", row);
			}

			sheet.Cells["A203"].Data = "February Orders";
			sheet.Cells["G203"].Data = "=SUM(G2:G202)";

			sheet.CellRanges["A203:F203"].Merge();

			sheet.FrozenRowCount = 1;

			IStyle style = sheet.Rows[0].Style;
			style.FontBold = true;
			style.FontSize = 10;
			style.HorizontalAlignment = HorizontalAlignment.Center;
			style.VerticalAlignment = VerticalAlignment.Middle;

			style = sheet.Rows[202].Style;
			style.FontBold = true;
			style.FontItalic = true;
			style.FontSize = 10;
			style.HorizontalAlignment = HorizontalAlignment.Right;
			style.VerticalAlignment = VerticalAlignment.Middle;
			style.PaddingRight = Measure.Point(5);

			style = sheet.CellRanges[0, 0, 6, 202].Style;
			style.BorderBottomColor = style.BorderLeftColor = style.BorderRightColor = style.BorderTopColor = SystemColors.ActiveBorder;

			style = sheet.CellRanges[0, 0, 6, 0].Style;
			style.BorderBottomSize = style.BorderLeftSize = style.BorderRightSize = style.BorderTopSize = Measure.Point(2);
			style = sheet.CellRanges[0, 202, 6, 202].Style;
			style.BorderBottomSize = style.BorderLeftSize = style.BorderRightSize = style.BorderTopSize = Measure.Point(2);

			sheet.EndInit();

			workbookView.ScrollY = 190;
		}

		private void button_Click(object sender, EventArgs e)
		{
			var activeSheet = workbookView.ActiveWorksheet;
			var activeCell = workbookView.ActiveCell;
			if (activeSheet.FrozenColumnCount > 0 || activeSheet.FrozenRowCount > 0)
			{
				activeSheet.FrozenColumnCount = 0;
				activeSheet.FrozenRowCount = 0;
			}
			else
			{
				if (activeCell.Column > 20 || activeCell.Row > 20)
				{
					MessageBox.Show("The maximum number of frozen columns and rows is 20.");
				}
				else
				{
					activeSheet.FrozenColumnCount = activeCell.Column;
					activeSheet.FrozenRowCount = activeCell.Row;
				}
			}
		}

		private static readonly Random rnd = new Random(DateTime.Now.Millisecond);
	}
}
