﻿//
// Copyright (c) 2016, MindFusion LLC - Bulgaria.
//

using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Windows.Forms;
using System.Diagnostics;

namespace MindFusion.Spreadsheet.WinForms.Samples.CS.Features
{
	public partial class HyperlinksForm : Form
	{
		public HyperlinksForm()
		{
			InitializeComponent();

			workbookView.HyperlinkClicked += new EventHandler<CellEventArgs>(workbookView_HyperlinkClicked);
			workbookView.ActiveCellChanged += new EventHandler(workbookView_ActiveCellChanged);

			var cell = workbookView.ActiveWorksheet.Cells[1, 1];
			cell.Data = "Created with Cell.Hyperlink";
			cell.SetHyperlink(HyperlinkType.WebAddress, "http://www.mindfusion.eu", "");

			cell = workbookView.ActiveWorksheet.Cells[1, 2];
			cell.Data = "=HYPERLINK(\"http://mindfusion.eu/Forum/YaBB.pl\", \"Created with the HYPERLINK function\")";
			
			
		}

		void workbookView_ActiveCellChanged(object sender, EventArgs e)
		{
			edit.Enabled = workbookView.ActiveCell.Hyperlink != null;
		}

		void workbookView_HyperlinkClicked(object sender, CellEventArgs e)
		{
			if (Control.ModifierKeys == Keys.Control)
			{
				try
				{
					Process.Start(e.Cell.Hyperlink.Target);
				}
				catch (Exception ex)
				{
					MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
				}
			}
		}

		private void addRemove_Click(object sender, EventArgs e)
		{
			var cell = workbookView.ActiveCell;
			if (cell == null)
				return;

			if (cell.Hyperlink == null)
			{
				HyperlinkForm hyperlinkForm = new HyperlinkForm(workbook, cell.Value != null ? cell.Value.ToString() : "");
				if (hyperlinkForm.ShowDialog(this) == DialogResult.OK)
				{
					cell.SetHyperlink(hyperlinkForm.Type, hyperlinkForm.Target, hyperlinkForm.SubTarget);
					cell.Hyperlink.ToolTip = hyperlinkForm.ToolTip;
					edit.Enabled = true;
				}
			}
			else
			{
				cell.RemoveHyperlink();
				edit.Enabled = false;
			}
		}

		private void edit_Click(object sender, EventArgs e)
		{
			var cell = workbookView.ActiveCell;
			if (cell == null || cell.Hyperlink == null)
				return;

			HyperlinkForm hyperlinkForm = new HyperlinkForm(workbook, cell.Hyperlink);
			if (hyperlinkForm.ShowDialog(this) == DialogResult.OK)
			{
				cell.Hyperlink.Type = hyperlinkForm.Type;
				cell.Hyperlink.Target = hyperlinkForm.Target;
				cell.Hyperlink.SubTarget = hyperlinkForm.SubTarget;
				cell.Hyperlink.ToolTip = hyperlinkForm.ToolTip;
			}
		}
	}
}
